pub struct Scope { /* private fields */ }Expand description
Scope is a structure containing all of the information required for the service to operate.
Implementations
Sourceimpl Scope
impl Scope
pub fn new(workdir: impl ToString) -> Self
pub fn context(&self) -> &Option<String>
pub fn workdir(&self) -> &String
pub fn set_workdir(&mut self, workdir: impl ToString)
pub fn with_workdir(self, workdir: impl ToString) -> Self
Sourcepub fn as_path_str(&self) -> String
pub fn as_path_str(&self) -> String
converts the scope into a string
Sourcepub fn set_context(&mut self, context: impl ToString)
pub fn set_context(&mut self, context: impl ToString)
sets the current context of the scope
Sourcepub fn with_context(self, context: impl ToString) -> Self
pub fn with_context(self, context: impl ToString) -> Self
consumes the current scope, returning another with the given context.
Sourcepub fn set_some_context(&mut self, rhs: Option<impl ToString>)
pub fn set_some_context(&mut self, rhs: Option<impl ToString>)
if the
pub fn set_some_workdir(&mut self, rhs: Option<impl ToString>)