pub struct Settings {
pub mode: Mode,
pub name: String,
pub network: NetworkConfig,
pub scope: Scope,
pub services: ServicesConfig,
pub version: String,
pub worker: Vec<WorkerConfig>,
}Fields
mode: Modename: Stringnetwork: NetworkConfigscope: Scopeservices: ServicesConfigversion: Stringworker: Vec<WorkerConfig>Implementations
Sourceimpl Settings
impl Settings
pub fn new(mode: Mode) -> Self
pub fn build() -> Result<Self, ConfigError>
pub async fn bind(&self) -> Result<TcpListener>
Sourcepub fn init_tracing(&self)
pub fn init_tracing(&self)
Initialize tracing modules
Sourcepub fn debug(self) -> Self
pub fn debug(self) -> Self
Returns a new Settings instance with the Mode set to Mode::Debug.
Sourcepub fn release(self) -> Self
pub fn release(self) -> Self
Returns a new Settings instance with the Mode set to Mode::Release.
pub fn mode(&self) -> &Mode
pub fn mode_mut(&mut self) -> &mut Mode
pub fn name(&self) -> &String
pub fn name_mut(&mut self) -> &mut String
pub fn network(&self) -> &NetworkConfig
pub fn network_mut(&mut self) -> &mut NetworkConfig
pub fn scope(&self) -> &Scope
pub fn scope_mut(&mut self) -> &mut Scope
pub fn services(&self) -> &ServicesConfig
pub fn services_mut(&mut self) -> &mut ServicesConfig
pub fn version(&self) -> &String
pub fn version_mut(&mut self) -> &mut String
pub fn set_mode(&mut self, mode: Mode)
pub fn with_mode(self, mode: Mode) -> Self
pub fn set_name(&mut self, name: impl ToString)
pub fn with_name(self, name: impl ToString) -> Self
pub fn set_scope(&mut self, scope: Scope)
pub fn with_scope(self, scope: Scope) -> Self
pub fn set_network(&mut self, network: NetworkConfig)
pub fn with_network(self, network: NetworkConfig) -> Self
pub fn set_services(&mut self, services: ServicesConfig)
pub fn with_services(self, services: ServicesConfig) -> Self
pub fn set_version(&mut self, version: impl ToString)
pub fn with_version(self, version: impl ToString) -> Self
Sourcepub fn workers(&self) -> &[WorkerConfig]
pub fn workers(&self) -> &[WorkerConfig]
Returns an immutable reference to the worker configuration.
Sourcepub fn workers_mut(&mut self) -> &mut Vec<WorkerConfig> ⓘ
pub fn workers_mut(&mut self) -> &mut Vec<WorkerConfig> ⓘ
Returns a mutable reference to the worker configuration.
Sourcepub fn push_worker(&mut self, worker: WorkerConfig)
pub fn push_worker(&mut self, worker: WorkerConfig)
Push a new worker configuration to the worker configuration list.
Sourcepub fn set_workdir(&mut self, workdir: impl ToString)
pub fn set_workdir(&mut self, workdir: impl ToString)
set the working directory of the scope
Sourcepub fn set_some_workdir(&mut self, workdir: Option<impl ToString>)
pub fn set_some_workdir(&mut self, workdir: Option<impl ToString>)
if the workdir is set, set it to the given workdir
Sourcepub fn set_scope_context(&mut self, context: impl ToString)
pub fn set_scope_context(&mut self, context: impl ToString)
Set the context of the scope
pub fn set_port(&mut self, port: u16)
pub fn set_log_level(&mut self, level: LogLevel)