pub struct ServerContext { /* private fields */ }Implementations
Sourceimpl ServerContext
impl ServerContext
pub fn new(addr: SocketAddr, scope: Scope) -> Self
pub fn localhost(port: u16, scope: Scope) -> Self
Sourcepub fn addr(&self) -> SocketAddr
pub fn addr(&self) -> SocketAddr
Returns a copy of the address the server is bound to
Sourcepub fn scope_mut(&mut self) -> &mut Scope
pub fn scope_mut(&mut self) -> &mut Scope
Returns a mutable reference to the Scope of the server
pub fn set_addr(&mut self, addr: SocketAddr)
pub fn with_addr(self, addr: SocketAddr) -> Self
pub fn set_scope(&mut self, scope: Scope)
pub fn with_scope(self, scope: Scope) -> Self
Sourcepub async fn listen(&self) -> TcpListener
pub async fn listen(&self) -> TcpListener
initialize a new listener, bound to the configured address